@@ -33,7 +33,7 @@ use warnings 'once';
 
 use Cwd 'abs_path';
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 use App::LXC::Container::Texts;
 
@@ -471,19 +471,19 @@ sub libraries_used($$)
     open my $file, '-|', 'file', $executable;	# Note that file never fails!
     my $info = join("\n", <$file>);
     close $file;
+    my @libraries = ();
     unless ($info =~
 	    m|^$executable:\s.*\sinterpreter\s[a-z/0-9]+\bld-linux[-a-z0-9]*\.so|
 	    or
 	    $info =~ m|^$executable:\s.*\sLSB shared object,|)
     {
 	error('bad_ldd_interpreter__1', $executable);
-	return ();
+	return @libraries;
     }
 
     # now call ldd:
     open my $ldd, '-|', 'ldd', $executable;	# doesn't fail in a useful way
     local $_;
-    my @libraries = ();
     while (<$ldd>)
     {
 	next unless s/\s+\(0x[0-9a-f]+\)\r?\n?$//;
